# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist, constr
from marqeta_client.models.fee_model import FeeModel

class ProgramTransfer(BaseModel):
    """
    ProgramTransfer
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    user_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'business_token' is null")
    business_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'user_token' is null")
    amount: Union[StrictFloat, StrictInt] = ...
    type_token: constr(strict=True, max_length=36, min_length=1) = ...
    tags: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    memo: Optional[constr(strict=True, max_length=99, min_length=1)] = None
    currency_code: StrictStr = ...
    fees: Optional[conlist(FeeModel)] = None
    __properties = ["token", "user_token", "business_token", "amount", "type_token", "tags", "memo", "currency_code", "fees"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ProgramTransfer:
        """Create an instance of ProgramTransfer from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in fees (list)
        _items = []
        if self.fees:
            for _item in self.fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fees'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ProgramTransfer:
        """Create an instance of ProgramTransfer from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ProgramTransfer.parse_obj(obj)

        _obj = ProgramTransfer.parse_obj({
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "amount": obj.get("amount"),
            "type_token": obj.get("type_token"),
            "tags": obj.get("tags"),
            "memo": obj.get("memo"),
            "currency_code": obj.get("currency_code"),
            "fees": [FeeModel.from_dict(_item) for _item in obj.get("fees")] if obj.get("fees") is not None else None
        })
        return _obj

