# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr, constr, validator

class PinRevealRequest(BaseModel):
    """
    PinRevealRequest
    """
    control_token: constr(strict=True, max_length=36, min_length=1) = ...
    cardholder_verification_method: StrictStr = Field(..., description="Verification method required")
    __properties = ["control_token", "cardholder_verification_method"]

    @validator('cardholder_verification_method')
    def cardholder_verification_method_validate_enum(cls, v):
        if v not in ('BIOMETRIC_FACE', 'BIOMETRIC_FINGERPRINT', 'LOGIN', 'EXP_CVV', 'OTP_CVV', 'OTP', 'OTHER'):
            raise ValueError("must be one of enum values ('BIOMETRIC_FACE', 'BIOMETRIC_FINGERPRINT', 'LOGIN', 'EXP_CVV', 'OTP_CVV', 'OTP', 'OTHER')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PinRevealRequest:
        """Create an instance of PinRevealRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PinRevealRequest:
        """Create an instance of PinRevealRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PinRevealRequest.parse_obj(obj)

        _obj = PinRevealRequest.parse_obj({
            "control_token": obj.get("control_token"),
            "cardholder_verification_method": obj.get("cardholder_verification_method")
        })
        return _obj

