# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr
from marqeta_client.models.deposit_deposit_response import DepositDepositResponse
from marqeta_client.models.pull_from_card_transfer_response import PullFromCardTransferResponse

class TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue(BaseModel):
    """
    TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue
    """
    tranlog_token: StrictStr = ...
    pull_from_card: Optional[PullFromCardTransferResponse] = None
    direct_deposit: Optional[DepositDepositResponse] = None
    __properties = ["tranlog_token", "pull_from_card", "direct_deposit"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue:
        """Create an instance of TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of pull_from_card
        if self.pull_from_card:
            _dict['pull_from_card'] = self.pull_from_card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of direct_deposit
        if self.direct_deposit:
            _dict['direct_deposit'] = self.direct_deposit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue:
        """Create an instance of TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue.parse_obj(obj)

        _obj = TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue.parse_obj({
            "tranlog_token": obj.get("tranlog_token"),
            "pull_from_card": PullFromCardTransferResponse.from_dict(obj.get("pull_from_card")) if obj.get("pull_from_card") is not None else None,
            "direct_deposit": DepositDepositResponse.from_dict(obj.get("direct_deposit")) if obj.get("direct_deposit") is not None else None
        })
        return _obj

