# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr

class DisputeTransactionRequest(BaseModel):
    """
    DisputeTransactionRequest
    """
    token: StrictStr = ...
    pan: StrictStr = ...
    reference_transaction_token: StrictStr = ...
    reason: StrictStr = ...
    cash_amount: Optional[Union[StrictFloat, StrictInt]] = None
    pending_amount: Optional[Union[StrictFloat, StrictInt]] = None
    include_acquirer_fees: Optional[StrictBool] = None
    case_management_identifier: Optional[StrictStr] = None
    __properties = ["token", "pan", "reference_transaction_token", "reason", "cash_amount", "pending_amount", "include_acquirer_fees", "case_management_identifier"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DisputeTransactionRequest:
        """Create an instance of DisputeTransactionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DisputeTransactionRequest:
        """Create an instance of DisputeTransactionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DisputeTransactionRequest.parse_obj(obj)

        _obj = DisputeTransactionRequest.parse_obj({
            "token": obj.get("token"),
            "pan": obj.get("pan"),
            "reference_transaction_token": obj.get("reference_transaction_token"),
            "reason": obj.get("reason"),
            "cash_amount": obj.get("cash_amount"),
            "pending_amount": obj.get("pending_amount"),
            "include_acquirer_fees": obj.get("include_acquirer_fees"),
            "case_management_identifier": obj.get("case_management_identifier")
        })
        return _obj

