# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, conlist
from marqeta_client.models.health_check_result import HealthCheckResult

class PingResponseExtended(BaseModel):
    """
    PingResponseExtended
    """
    success: Optional[StrictBool] = None
    version: Optional[StrictStr] = None
    revision: Optional[StrictStr] = None
    timestamp: Optional[StrictStr] = None
    env: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    system_components: Optional[conlist(HealthCheckResult, unique_items=True)] = None
    __properties = ["success", "version", "revision", "timestamp", "env", "id", "system_components"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PingResponseExtended:
        """Create an instance of PingResponseExtended from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in system_components (list)
        _items = []
        if self.system_components:
            for _item in self.system_components:
                if _item:
                    _items.append(_item.to_dict())
            _dict['system_components'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PingResponseExtended:
        """Create an instance of PingResponseExtended from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PingResponseExtended.parse_obj(obj)

        _obj = PingResponseExtended.parse_obj({
            "success": obj.get("success"),
            "version": obj.get("version"),
            "revision": obj.get("revision"),
            "timestamp": obj.get("timestamp"),
            "env": obj.get("env"),
            "id": obj.get("id"),
            "system_components": [HealthCheckResult.from_dict(_item) for _item in obj.get("system_components")] if obj.get("system_components") is not None else None
        })
        return _obj

