# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, constr, validator

class AchPartnerRequestModel(BaseModel):
    """
    AchPartnerRequestModel
    """
    idempotent_hash: Optional[StrictStr] = Field(None, alias="idempotentHash")
    token: Optional[StrictStr] = None
    partner_account_link_reference_token: StrictStr = ...
    partner: StrictStr = ...
    user_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'business_token' is null")
    business_token: Optional[constr(strict=True, max_length=36, min_length=1)] = Field(None, description="Required if 'user_token' is null")
    is_default_account: Optional[StrictBool] = False
    __properties = ["idempotentHash", "token", "partner_account_link_reference_token", "partner", "user_token", "business_token", "is_default_account"]

    @validator('partner')
    def partner_validate_enum(cls, v):
        if v not in ('PLAID'):
            raise ValueError("must be one of enum values ('PLAID')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AchPartnerRequestModel:
        """Create an instance of AchPartnerRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AchPartnerRequestModel:
        """Create an instance of AchPartnerRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AchPartnerRequestModel.parse_obj(obj)

        _obj = AchPartnerRequestModel.parse_obj({
            "idempotent_hash": obj.get("idempotentHash"),
            "token": obj.get("token"),
            "partner_account_link_reference_token": obj.get("partner_account_link_reference_token"),
            "partner": obj.get("partner"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "is_default_account": obj.get("is_default_account") if obj.get("is_default_account") is not None else False
        })
        return _obj

