# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, StrictBool, StrictStr
from marqeta_client.models.funding_source_model import FundingSourceModel

class ChargebackFundingSourceModel(FundingSourceModel):
    """
    ChargebackFundingSourceModel
    """
    name: StrictStr = ...
    credit: StrictBool = ...
    __properties = ["token", "active", "is_default_account", "created_time", "last_modified_time", "type", "name", "credit"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ChargebackFundingSourceModel:
        """Create an instance of ChargebackFundingSourceModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ChargebackFundingSourceModel:
        """Create an instance of ChargebackFundingSourceModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ChargebackFundingSourceModel.parse_obj(obj)

        _obj = ChargebackFundingSourceModel.parse_obj({
            "token": obj.get("token"),
            "active": obj.get("active") if obj.get("active") is not None else False,
            "is_default_account": obj.get("is_default_account") if obj.get("is_default_account") is not None else False,
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "type": obj.get("type"),
            "name": obj.get("name"),
            "credit": obj.get("credit")
        })
        return _obj

