# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr

class AutoCommandoModeProgramFundingSourceResponse(BaseModel):
    """
    AutoCommandoModeProgramFundingSourceResponse
    """
    name: constr(strict=True, max_length=50, min_length=1) = ...
    active: Optional[StrictBool] = None
    token: constr(strict=True, max_length=36, min_length=1) = ...
    created_time: datetime = ...
    last_modified_time: datetime = ...
    account: StrictStr = ...
    __properties = ["name", "active", "token", "created_time", "last_modified_time", "account"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AutoCommandoModeProgramFundingSourceResponse:
        """Create an instance of AutoCommandoModeProgramFundingSourceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AutoCommandoModeProgramFundingSourceResponse:
        """Create an instance of AutoCommandoModeProgramFundingSourceResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AutoCommandoModeProgramFundingSourceResponse.parse_obj(obj)

        _obj = AutoCommandoModeProgramFundingSourceResponse.parse_obj({
            "name": obj.get("name"),
            "active": obj.get("active"),
            "token": obj.get("token"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "account": obj.get("account")
        })
        return _obj

