# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, validator
from marqeta_client.models.carrier import Carrier
from marqeta_client.models.images import Images
from marqeta_client.models.text import Text

class CardPersonalization(BaseModel):
    """
    CardPersonalization
    """
    text: Text = ...
    images: Optional[Images] = None
    carrier: Optional[Carrier] = None
    perso_type: Optional[StrictStr] = None
    __properties = ["text", "images", "carrier", "perso_type"]

    @validator('perso_type')
    def perso_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('EMBOSS', 'LASER', 'FLAT'):
            raise ValueError("must be one of enum values ('EMBOSS', 'LASER', 'FLAT')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardPersonalization:
        """Create an instance of CardPersonalization from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of text
        if self.text:
            _dict['text'] = self.text.to_dict()
        # override the default output from pydantic by calling `to_dict()` of images
        if self.images:
            _dict['images'] = self.images.to_dict()
        # override the default output from pydantic by calling `to_dict()` of carrier
        if self.carrier:
            _dict['carrier'] = self.carrier.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardPersonalization:
        """Create an instance of CardPersonalization from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardPersonalization.parse_obj(obj)

        _obj = CardPersonalization.parse_obj({
            "text": Text.from_dict(obj.get("text")) if obj.get("text") is not None else None,
            "images": Images.from_dict(obj.get("images")) if obj.get("images") is not None else None,
            "carrier": Carrier.from_dict(obj.get("carrier")) if obj.get("carrier") is not None else None,
            "perso_type": obj.get("perso_type")
        })
        return _obj

