# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, validator

class NetworkFeeModel(BaseModel):
    """
    NetworkFeeModel
    """
    type: Optional[StrictStr] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    credit_debit: Optional[StrictStr] = Field(None, description="C = credit; D = debit")
    __properties = ["type", "amount", "credit_debit"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('ISSUER_FEE', 'SWITCH_FEE', 'PINDEBIT_ASSOC_FEE', 'ACQUIRER_FEE', 'INTERCHANGE_FEE', 'CUR_CONV_CARDHOLDER_FEE', 'CUR_CONV_ISSUER_FEE', 'CROSS_BORDER_ISSUER_FEE'):
            raise ValueError("must be one of enum values ('ISSUER_FEE', 'SWITCH_FEE', 'PINDEBIT_ASSOC_FEE', 'ACQUIRER_FEE', 'INTERCHANGE_FEE', 'CUR_CONV_CARDHOLDER_FEE', 'CUR_CONV_ISSUER_FEE', 'CROSS_BORDER_ISSUER_FEE')")
        return v

    @validator('credit_debit')
    def credit_debit_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('C', 'D'):
            raise ValueError("must be one of enum values ('C', 'D')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NetworkFeeModel:
        """Create an instance of NetworkFeeModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NetworkFeeModel:
        """Create an instance of NetworkFeeModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return NetworkFeeModel.parse_obj(obj)

        _obj = NetworkFeeModel.parse_obj({
            "type": obj.get("type"),
            "amount": obj.get("amount"),
            "credit_debit": obj.get("credit_debit")
        })
        return _obj

