# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, StrictStr, constr, validator

class DigitalWalletAndroidPayProvisionRequest(BaseModel):
    """
    DigitalWalletAndroidPayProvisionRequest
    """
    card_token: constr(strict=True, max_length=36, min_length=1) = ...
    device_type: StrictStr = ...
    provisioning_app_version: constr(strict=True, max_length=50, min_length=1) = ...
    wallet_account_id: constr(strict=True, max_length=50, min_length=1) = ...
    device_id: constr(strict=True, max_length=24, min_length=1) = ...
    __properties = ["card_token", "device_type", "provisioning_app_version", "wallet_account_id", "device_id"]

    @validator('device_type')
    def device_type_validate_enum(cls, v):
        if v not in ('MOBILE_PHONE', 'WATCH', 'TABLET'):
            raise ValueError("must be one of enum values ('MOBILE_PHONE', 'WATCH', 'TABLET')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletAndroidPayProvisionRequest:
        """Create an instance of DigitalWalletAndroidPayProvisionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletAndroidPayProvisionRequest:
        """Create an instance of DigitalWalletAndroidPayProvisionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletAndroidPayProvisionRequest.parse_obj(obj)

        _obj = DigitalWalletAndroidPayProvisionRequest.parse_obj({
            "card_token": obj.get("card_token"),
            "device_type": obj.get("device_type"),
            "provisioning_app_version": obj.get("provisioning_app_version"),
            "wallet_account_id": obj.get("wallet_account_id"),
            "device_id": obj.get("device_id")
        })
        return _obj

