# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, conlist
from marqeta_client.models.cardholder_balance import CardholderBalance
from marqeta_client.models.link import Link

class CardholderBalances(BaseModel):
    """
    CardholderBalances
    """
    gpa: CardholderBalance = ...
    links: conlist(Link, unique_items=True) = ...
    __properties = ["gpa", "links"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardholderBalances:
        """Create an instance of CardholderBalances from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of gpa
        if self.gpa:
            _dict['gpa'] = self.gpa.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardholderBalances:
        """Create an instance of CardholderBalances from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardholderBalances.parse_obj(obj)

        _obj = CardholderBalances.parse_obj({
            "gpa": CardholderBalance.from_dict(obj.get("gpa")) if obj.get("gpa") is not None else None,
            "links": [Link.from_dict(_item) for _item in obj.get("links")] if obj.get("links") is not None else None
        })
        return _obj

