# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictStr

class DigitalWalletApplePayProvisionResponse(BaseModel):
    """
    DigitalWalletApplePayProvisionResponse
    """
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    card_token: StrictStr = ...
    encrypted_pass_data: StrictStr = ...
    activation_data: StrictStr = ...
    ephemeral_public_key: StrictStr = ...
    __properties = ["created_time", "last_modified_time", "card_token", "encrypted_pass_data", "activation_data", "ephemeral_public_key"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletApplePayProvisionResponse:
        """Create an instance of DigitalWalletApplePayProvisionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletApplePayProvisionResponse:
        """Create an instance of DigitalWalletApplePayProvisionResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletApplePayProvisionResponse.parse_obj(obj)

        _obj = DigitalWalletApplePayProvisionResponse.parse_obj({
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "card_token": obj.get("card_token"),
            "encrypted_pass_data": obj.get("encrypted_pass_data"),
            "activation_data": obj.get("activation_data"),
            "ephemeral_public_key": obj.get("ephemeral_public_key")
        })
        return _obj

