# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, conlist
from marqeta_client.models.gl_entry import GLEntry

class GlTransactionRequest(BaseModel):
    """
    GlTransactionRequest
    """
    entries: conlist(GLEntry) = ...
    detail: Optional[StrictStr] = None
    cardholder_visible: Optional[StrictBool] = None
    trigger_webhook: Optional[StrictBool] = None
    reference_transaction_token: Optional[StrictStr] = None
    __properties = ["entries", "detail", "cardholder_visible", "trigger_webhook", "reference_transaction_token"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GlTransactionRequest:
        """Create an instance of GlTransactionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in entries (list)
        _items = []
        if self.entries:
            for _item in self.entries:
                if _item:
                    _items.append(_item.to_dict())
            _dict['entries'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GlTransactionRequest:
        """Create an instance of GlTransactionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GlTransactionRequest.parse_obj(obj)

        _obj = GlTransactionRequest.parse_obj({
            "entries": [GLEntry.from_dict(_item) for _item in obj.get("entries")] if obj.get("entries") is not None else None,
            "detail": obj.get("detail"),
            "cardholder_visible": obj.get("cardholder_visible"),
            "trigger_webhook": obj.get("trigger_webhook"),
            "reference_transaction_token": obj.get("reference_transaction_token")
        })
        return _obj

