# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictStr, confloat, conint, constr
from marqeta_client.models.ptc_soft_descriptor import PTCSoftDescriptor

class PushToCardDisburseRequest(BaseModel):
    """
    PushToCardDisburseRequest
    """
    tags: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    memo: Optional[constr(strict=True, max_length=99, min_length=1)] = None
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    currency_code: StrictStr = ...
    amount: Union[confloat(le=5E+4, ge=0.01, strict=True), conint(le=50000, ge=1, strict=True)] = ...
    payment_instrument_token: constr(strict=True, max_length=36, min_length=1) = ...
    soft_descriptor: Optional[PTCSoftDescriptor] = None
    __properties = ["tags", "memo", "token", "currency_code", "amount", "payment_instrument_token", "soft_descriptor"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PushToCardDisburseRequest:
        """Create an instance of PushToCardDisburseRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of soft_descriptor
        if self.soft_descriptor:
            _dict['soft_descriptor'] = self.soft_descriptor.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PushToCardDisburseRequest:
        """Create an instance of PushToCardDisburseRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return PushToCardDisburseRequest.parse_obj(obj)

        _obj = PushToCardDisburseRequest.parse_obj({
            "tags": obj.get("tags"),
            "memo": obj.get("memo"),
            "token": obj.get("token"),
            "currency_code": obj.get("currency_code"),
            "amount": obj.get("amount"),
            "payment_instrument_token": obj.get("payment_instrument_token"),
            "soft_descriptor": PTCSoftDescriptor.from_dict(obj.get("soft_descriptor")) if obj.get("soft_descriptor") is not None else None
        })
        return _obj

