# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, StrictFloat, StrictInt, conlist, constr
from marqeta_client.models.network_fee_model import NetworkFeeModel
from marqeta_client.models.transaction_options import TransactionOptions
from marqeta_client.models.webhook import Webhook

class AuthorizationAdviceModel(BaseModel):
    """
    AuthorizationAdviceModel
    """
    amount: Union[StrictFloat, StrictInt] = ...
    network_fees: Optional[conlist(NetworkFeeModel)] = None
    webhook: Optional[Webhook] = None
    original_transaction_token: constr(strict=True, max_length=36, min_length=1) = ...
    transaction_options: Optional[TransactionOptions] = None
    __properties = ["amount", "network_fees", "webhook", "original_transaction_token", "transaction_options"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AuthorizationAdviceModel:
        """Create an instance of AuthorizationAdviceModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in network_fees (list)
        _items = []
        if self.network_fees:
            for _item in self.network_fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['network_fees'] = _items
        # override the default output from pydantic by calling `to_dict()` of webhook
        if self.webhook:
            _dict['webhook'] = self.webhook.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction_options
        if self.transaction_options:
            _dict['transaction_options'] = self.transaction_options.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AuthorizationAdviceModel:
        """Create an instance of AuthorizationAdviceModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AuthorizationAdviceModel.parse_obj(obj)

        _obj = AuthorizationAdviceModel.parse_obj({
            "amount": obj.get("amount"),
            "network_fees": [NetworkFeeModel.from_dict(_item) for _item in obj.get("network_fees")] if obj.get("network_fees") is not None else None,
            "webhook": Webhook.from_dict(obj.get("webhook")) if obj.get("webhook") is not None else None,
            "original_transaction_token": obj.get("original_transaction_token"),
            "transaction_options": TransactionOptions.from_dict(obj.get("transaction_options")) if obj.get("transaction_options") is not None else None
        })
        return _obj

