# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, constr, validator

class JitFundingProgramFundingSource(BaseModel):
    """
    JitFundingProgramFundingSource
    """
    enabled: Optional[StrictBool] = False
    funding_source_token: Optional[constr(strict=True, max_length=36, min_length=0)] = Field(None, description="required if enabled")
    refunds_destination: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    __properties = ["enabled", "funding_source_token", "refunds_destination"]

    @validator('refunds_destination')
    def refunds_destination_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PROGRAM_FUNDING_SOURCE', 'GPA', 'WATERFALL'):
            raise ValueError("must be one of enum values ('PROGRAM_FUNDING_SOURCE', 'GPA', 'WATERFALL')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> JitFundingProgramFundingSource:
        """Create an instance of JitFundingProgramFundingSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> JitFundingProgramFundingSource:
        """Create an instance of JitFundingProgramFundingSource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return JitFundingProgramFundingSource.parse_obj(obj)

        _obj = JitFundingProgramFundingSource.parse_obj({
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else False,
            "funding_source_token": obj.get("funding_source_token"),
            "refunds_destination": obj.get("refunds_destination")
        })
        return _obj

