# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr, constr
from marqeta_client.models.real_time_fee_assessment_request import RealTimeFeeAssessmentRequest

class FeeUpdateRequest(BaseModel):
    """
    FeeUpdateRequest
    """
    name: Optional[constr(strict=True, max_length=50, min_length=1)] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    tags: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    currency_code: Optional[StrictStr] = None
    active: Optional[StrictBool] = True
    real_time_assessment: Optional[RealTimeFeeAssessmentRequest] = None
    __properties = ["name", "amount", "tags", "currency_code", "active", "real_time_assessment"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FeeUpdateRequest:
        """Create an instance of FeeUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of real_time_assessment
        if self.real_time_assessment:
            _dict['real_time_assessment'] = self.real_time_assessment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FeeUpdateRequest:
        """Create an instance of FeeUpdateRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FeeUpdateRequest.parse_obj(obj)

        _obj = FeeUpdateRequest.parse_obj({
            "name": obj.get("name"),
            "amount": obj.get("amount"),
            "tags": obj.get("tags"),
            "currency_code": obj.get("currency_code"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "real_time_assessment": RealTimeFeeAssessmentRequest.from_dict(obj.get("real_time_assessment")) if obj.get("real_time_assessment") is not None else None
        })
        return _obj

