# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr, validator
from marqeta_client.models.digital_wallet_token_hash import DigitalWalletTokenHash

class DigitalWalletTokenTransitionRequest(BaseModel):
    """
    DigitalWalletTokenTransitionRequest
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    reason_code: Optional[StrictStr] = None
    token_reference_id: Optional[StrictStr] = None
    channel: Optional[StrictStr] = None
    digital_wallet_token: DigitalWalletTokenHash = ...
    state: StrictStr = ...
    reason: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    override_tsp_error: Optional[StrictBool] = False
    __properties = ["token", "reason_code", "token_reference_id", "channel", "digital_wallet_token", "state", "reason", "override_tsp_error"]

    @validator('reason_code')
    def reason_code_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31'):
            raise ValueError("must be one of enum values ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31')")
        return v

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('TOKEN_SERVICE_PROVIDER', 'TOKEN_SERVICE_PROVIDER_API', 'DIGITAL_WALLET', 'API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM'):
            raise ValueError("must be one of enum values ('TOKEN_SERVICE_PROVIDER', 'TOKEN_SERVICE_PROVIDER_API', 'DIGITAL_WALLET', 'API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('ACTIVE', 'SUSPENDED', 'TERMINATED'):
            raise ValueError("must be one of enum values ('ACTIVE', 'SUSPENDED', 'TERMINATED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletTokenTransitionRequest:
        """Create an instance of DigitalWalletTokenTransitionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_token
        if self.digital_wallet_token:
            _dict['digital_wallet_token'] = self.digital_wallet_token.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletTokenTransitionRequest:
        """Create an instance of DigitalWalletTokenTransitionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletTokenTransitionRequest.parse_obj(obj)

        _obj = DigitalWalletTokenTransitionRequest.parse_obj({
            "token": obj.get("token"),
            "reason_code": obj.get("reason_code"),
            "token_reference_id": obj.get("token_reference_id"),
            "channel": obj.get("channel"),
            "digital_wallet_token": DigitalWalletTokenHash.from_dict(obj.get("digital_wallet_token")) if obj.get("digital_wallet_token") is not None else None,
            "state": obj.get("state"),
            "reason": obj.get("reason"),
            "override_tsp_error": obj.get("override_tsp_error") if obj.get("override_tsp_error") is not None else False
        })
        return _obj

