# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, validator

class RealTimeFeeAssessmentRequest(BaseModel):
    """
    RealTimeFeeAssessmentRequest
    """
    transaction_type: Optional[StrictStr] = None
    international_enabled: Optional[StrictBool] = False
    domestic_enabled: Optional[StrictBool] = False
    __properties = ["transaction_type", "international_enabled", "domestic_enabled"]

    @validator('transaction_type')
    def transaction_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('authorization', 'pindebit.atm.withdrawal', 'pindebit'):
            raise ValueError("must be one of enum values ('authorization', 'pindebit.atm.withdrawal', 'pindebit')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RealTimeFeeAssessmentRequest:
        """Create an instance of RealTimeFeeAssessmentRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RealTimeFeeAssessmentRequest:
        """Create an instance of RealTimeFeeAssessmentRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return RealTimeFeeAssessmentRequest.parse_obj(obj)

        _obj = RealTimeFeeAssessmentRequest.parse_obj({
            "transaction_type": obj.get("transaction_type"),
            "international_enabled": obj.get("international_enabled") if obj.get("international_enabled") is not None else False,
            "domestic_enabled": obj.get("domestic_enabled") if obj.get("domestic_enabled") is not None else False
        })
        return _obj

