# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from marqeta_client.models.internal_crypto_key_request import InternalCryptoKeyRequest

class InternalCryptoKeyRequestModel(BaseModel):
    """
    InternalCryptoKeyRequestModel
    """
    crypto_keys: conlist(InternalCryptoKeyRequest, max_items=2147483647, min_items=1) = Field(..., description="A list of 'internal crypto key' items")
    __properties = ["crypto_keys"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalCryptoKeyRequestModel:
        """Create an instance of InternalCryptoKeyRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in crypto_keys (list)
        _items = []
        if self.crypto_keys:
            for _item in self.crypto_keys:
                if _item:
                    _items.append(_item.to_dict())
            _dict['crypto_keys'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalCryptoKeyRequestModel:
        """Create an instance of InternalCryptoKeyRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalCryptoKeyRequestModel.parse_obj(obj)

        _obj = InternalCryptoKeyRequestModel.parse_obj({
            "crypto_keys": [InternalCryptoKeyRequest.from_dict(_item) for _item in obj.get("crypto_keys")] if obj.get("crypto_keys") is not None else None
        })
        return _obj

