# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt

class AchVerificationModel(BaseModel):
    """
    AchVerificationModel
    """
    verify_amount1: Optional[Union[StrictFloat, StrictInt]] = None
    verify_amount2: Optional[Union[StrictFloat, StrictInt]] = None
    active: Optional[StrictBool] = False
    __properties = ["verify_amount1", "verify_amount2", "active"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AchVerificationModel:
        """Create an instance of AchVerificationModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AchVerificationModel:
        """Create an instance of AchVerificationModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AchVerificationModel.parse_obj(obj)

        _obj = AchVerificationModel.parse_obj({
            "verify_amount1": obj.get("verify_amount1"),
            "verify_amount2": obj.get("verify_amount2"),
            "active": obj.get("active") if obj.get("active") is not None else False
        })
        return _obj

