# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, constr, validator

class FileProcessingRequest(BaseModel):
    """
    FileProcessingRequest
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    file_process_type: StrictStr = ...
    source_file: constr(strict=True, max_length=512, min_length=0) = ...
    archive_file: Optional[constr(strict=True, max_length=512, min_length=0)] = None
    __properties = ["token", "file_process_type", "source_file", "archive_file"]

    @validator('file_process_type')
    def file_process_type_validate_enum(cls, v):
        if v not in ('MASTERCARD_CLEARING', 'VISA_CLEARING', 'PULSE_CLEARING', 'DISCOVER_CLEARING'):
            raise ValueError("must be one of enum values ('MASTERCARD_CLEARING', 'VISA_CLEARING', 'PULSE_CLEARING', 'DISCOVER_CLEARING')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FileProcessingRequest:
        """Create an instance of FileProcessingRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FileProcessingRequest:
        """Create an instance of FileProcessingRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FileProcessingRequest.parse_obj(obj)

        _obj = FileProcessingRequest.parse_obj({
            "token": obj.get("token"),
            "file_process_type": obj.get("file_process_type"),
            "source_file": obj.get("source_file"),
            "archive_file": obj.get("archive_file")
        })
        return _obj

