# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, constr

class DirectDepositAccountResponse(BaseModel):
    """
    DirectDepositAccountResponse
    """
    account_number: constr(strict=True, max_length=17, min_length=13) = ...
    routing_number: constr(strict=True, max_length=9, min_length=9) = ...
    token: constr(strict=True, max_length=36, min_length=36) = ...
    user_token: constr(strict=True, max_length=36, min_length=36) = ...
    business_token: constr(strict=True, max_length=36, min_length=36) = ...
    state: constr(strict=True, max_length=10, min_length=6) = ...
    allow_immediate_credit: StrictBool = ...
    type: Optional[constr(strict=True, max_length=36, min_length=7)] = None
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    __properties = ["account_number", "routing_number", "token", "user_token", "business_token", "state", "allow_immediate_credit", "type", "created_time", "last_modified_time"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DirectDepositAccountResponse:
        """Create an instance of DirectDepositAccountResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DirectDepositAccountResponse:
        """Create an instance of DirectDepositAccountResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DirectDepositAccountResponse.parse_obj(obj)

        _obj = DirectDepositAccountResponse.parse_obj({
            "account_number": obj.get("account_number"),
            "routing_number": obj.get("routing_number"),
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "state": obj.get("state"),
            "allow_immediate_credit": obj.get("allow_immediate_credit") if obj.get("allow_immediate_credit") is not None else False,
            "type": obj.get("type"),
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time")
        })
        return _obj

